/*
 * $LastChangedRevision: 2682 $
 * $LastChangedDate:: 2022-07-25 14:21:39 +0200#$
 *
 * This file is part of X2C. http://x2c.lcm.at/
 *
 * Copyright (c) 2022, Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 */
/*
 * This file is licensed according to the BSD 3-clause license as follows:
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the "Linz Center of Mechatronics GmbH" and "LCM" nor
 *       the names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL "Linz Center of Mechatronics GmbH" BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#include "Hardware.h"

/* private prototypes */
static void sendSerial(tSerial* serialSTM32F0, uint8 data);
static uint8 receiveSerial(tSerial* serialSTM32F0);
static uint8 isReceiveDataAvailable(tSerial* serialSTM32F0);
static uint8 isSendReady(tSerial* serialSTM32F0);


/**
 * @brief Initialization of serial interface.
 */
void initSerial(tSerial* serialSTM32F0)
{
	serialSTM32F0->send = (void (*)(tInterface*, uint8))sendSerial;
	serialSTM32F0->receive = (uint8 (*)(tInterface*))receiveSerial;
	serialSTM32F0->isReceiveDataAvailable = (uint8 (*)(tInterface*))isReceiveDataAvailable;
	serialSTM32F0->isSendReady = (uint8 (*)(tInterface*))isSendReady;
}

/**
 * @brief Routine to send data over serial interface.
 * 
 * @param serial Serial interface object.
 * @param data Data byte to send.
 */
static void sendSerial(tSerial* serialSTM32F0, uint8 data)
{
	USART1->TDR = data;
}

/**
 * @brief Routine to fetch data from the serial interface.
 * 
 * @param serial Serial interface object.
 * @return Received data byte.
 */
static uint8 receiveSerial(tSerial* serialSTM32F0)
{
	uint8 data;
	data = USART1->RDR;
	return (data);
}

/**
 * @brief Routine to check if data from the serial interface is available.
 * 
 * @param serial Serial interface object.
 * @return 1 when data is available, 0 otherwise.
 */
static uint8 isReceiveDataAvailable(tSerial* serialSTM32F0)
{
	return (USART1->ISR & USART_ISR_RXNE);
}

/**
 * @brief Routine to check if data can be send over the serial interface.
 *  
 * @param serial Serial interface object.
 * @return 1 when data can be send, 0 otherwise.
 */
static uint8 isSendReady(tSerial* serialSTM32F0)
{
	return (USART1->ISR & USART_ISR_TXE);
}
